/*-----------------------------------------------------------------------
dreams_table4.do

Stata do file to replicate table 4 of the article
'City of dreams',
by Jorge De la Roca, Gianmarco Ottaviano and Diego Puga,
Journal of the European Economic Association
-----------------------------------------------------------------------*/

* initialise
clear
set more off
set varabbrev off

* read panel
use ../../data/processed/nlsy_panel_sample, clear

** set up duration framework
sort person_id year
* location during junior period
replace cbsa_pop2010 = 0 if missing(cbsa_pop2010)
gen big = 1 if cbsa_pop2010 >= $size_big
replace big = 0 if cbsa_pop2010 < $size_big
gen big_junior = 1 if junior_period == 1 & big == 1
replace big_junior = 0 if junior_period == 1 & big == 0
egen small_junior = max(big_junior), by (person_id)
* identify moving episodes (moves after junior period)
gen junior_yr = year if junior_period == 1
egen junior_year = min(junior_yr), by (person_id)
gen move_ = 1 if cbsa != cbsa[_n+1] & person_id == person_id[_n+1] & year >= junior_year
replace move_ = 1 if fips != fips[_n+1] & missing(cbsa) & missing(cbsa[_n+1]) & person_id == person_id[_n+1] & year >= junior_year & missing(move_)
* keep only first observed move
egen move_cbsa = seq() if !missing(move_), by(person_id)
replace move_cbsa = . if move_cbsa > 1 & !missing(move_cbsa)
gen move_yr = year if move_cbsa == 1
egen move_year = min(move_yr), by (person_id)
replace move_cbsa = 0 if missing(move_cbsa) & year >= junior_year
replace move_cbsa = . if move_cbsa == 0 & year > move_year
* duration dependence
gen yrs_dd = year if !missing(move_cbsa)
replace yrs_dd = yrs_dd - junior_year + 1
egen yrs_since = cut(yrs_dd), group(6) icodes

** dependent variables
* between junior and senior period, remained in same small city when senior = 0, moved to another small city = 1, or moved to a big city = 2
gen move_fm_small = 2 if move_cbsa == 1 & cbsa_pop2010[_n+1] >= $size_big & small_junior == 0
replace move_fm_small = 1 if move_cbsa == 1 & missing(move_fm_small) & small_junior == 0
replace move_fm_small = 0 if move_cbsa == 0 & small_junior == 0
* between junior and senior period, remained in same big city when senior = 0, moved to a small city = 1, or moved to another big city = 2
gen move_fm_big = 2 if move_cbsa == 1 & cbsa_pop2010[_n+1] >= $size_big & small_junior == 1
replace move_fm_big = 1 if move_cbsa == 1 & missing(move_fm_big) & small_junior == 1
replace move_fm_big = 0 if move_cbsa == 0 & small_junior == 1

** additional controls
* normalize experience
replace experience = 0 if missing(experience)
gen exp_jr = experience if junior_period == 1
egen exp_junior = min(exp_jr), by (person_id)
replace experience = experience - exp_junior
* normalize tenure
replace tenure = 0 if missing(tenure)
replace tenure = experience if tenure > experience
* identify unemployment spells
replace unemployment = 0 if missing(unemployment)
gen diff_unemp = unemployment - unemployment[_n-1] if person_id == person_id[_n-1]
replace diff_unemp = 1 if diff_unemp > 0 & !missing(diff_unemp)

** minor adjustments
* only 1 individual was born in 1965 (replace by 1964)
replace birth_year = 1964 if birth_year == 1965
* replace missing cbsa with fips to cluster standard errors
gen cbsa_cluster = cbsa * 100
replace cbsa_cluster = fips if missing(cbsa_cluster)

** table
* label variables
label var self_pctl "Self-confidence percentile"
label var afqt_pctl "Ability percentile"
label var experience "Experience"
label var tenure "Tenure"
label var diff_unemp "Unemployed"
label var sex "Male"
label var hispanic "Hispanic"
label var black "Black"
label var educ_high_school "High-school graduate"
label var educ_some_college "Some college"
label var educ_college "College graduate"
label var never_married "Never married"
label var any_children "One or more children"
label var spouse_work_ft "Full-time working spouse"
label var cbsa_junior_sameas_at14 "Same city when junior and age 14"
* define controls
local tablecontrols "self_pctl afqt_pctl experience tenure diff_unemp sex hispanic black educ_high_school educ_some_college educ_college never_married any_children spouse_work_ft cbsa_junior_sameas_at14"
local controls "self_pctl afqt_pctl experience tenure diff_unemp sex hispanic black educ_high_school educ_some_college educ_college never_married any_children spouse_work_ft cbsa_junior_sameas_at14 i.birth_year i.yrs_since"
mlogit move_fm_small `controls' , rrr cluster(cbsa_cluster)
test [1]self_pctl = [2]self_pctl
test [1]afqt_pctl = [2]afqt_pctl
estimates store log4_a
mlogit move_fm_big `controls', rrr cluster(cbsa_cluster)
test [1]self_pctl = [2]self_pctl
test [1]afqt_pctl = [2]afqt_pctl
estimates store log4_b
* write latex file
estout log4_* using "../../results/dreams_table4.tex", keep(`tablecontrols') order(`tablecontrols') cells(b(star fmt(%9.4f)) se(par fmt(%9.4f))) starlevels($^{*}$ 0.10 $^{**}$ 0.05 $^{***}$ 0.01) substitute( "(" "\raisebox{.7ex}[0pt]{\scriptsize (" ")" ")}") label collabels(,none) eqlabels(,none) mlabels(,none) nonumbers noomitted stats(N r2_p, labels("Observations" "Pseudo \$R^2$") fmt(%9.0fc %9.4f)) indicate("Years since junior period indicators = 1.yrs_since") eform unstack style(tex) replace
estimates drop log4_*

